@@ -2,7 +2,7 @@ from ai_harness import harnessutils as utils
 from ai_harness.inspector import Inspector
 import argparse
 from ai_harness.configclasses import configclass, field, fields, Field, is_configclass, make_configclass, merge_fields, \
-    export
+    export, to_json_string
 
 
 def arg(value, help):
@@ -38,7 +38,7 @@ class ConfigInspector:
         this_field = self._get_fields(root_parent).get(name)
         if this_field: return root_parent, this_field
         for sub_name, sub_config in self._get_configClasses(root_parent).items():
-            this_field = self.get_field_with_parent(name, sub_config)
+            parent, this_field = self.get_field_with_parent(name, sub_config)
             if this_field: return sub_config, this_field
         return None, None
 
@@ -215,10 +215,10 @@ class Arguments:
 
         return self
 
-    def parse(self, args=None):
+    def parse(self, args=None, with_group_prefix=False):
         args, _ = self.parser.parse_known_args(args)
 
-        for k, _ in args.__dict__.items():
-            Inspector.set_attr_from(args, self.destObj, k, False, True)
+        for k, v in args.__dict__.items():
+            if v: self.configInspector.set(k, v, None, with_group_prefix)
 
         return self.destObj
